@@ -255,6 +255,15 @@ class Type(sequence_ordered(), tree(separator='\\'), ModelSQL, ModelView):
                 ~Eval('comparison', False)),
             ]
 
+    @classmethod
+    def copy(cls, types, default=None):
+        if default is None:
+            default = {}
+        else:
+            default = default.copy()
+        default.setdefault('template', None)
+        return super().copy(types, default=default)
+
     @classmethod
     def delete(cls, types):
         types = cls.search([
@@ -942,7 +951,8 @@ class Account(ActivePeriodMixin, tree(), ModelSQL, ModelView):
         'reconcile', 'kind', 'deferral', 'party_required',
         'general_ledger_balance', 'taxes']
 
-    @fields.depends('parent', *__on_change_parent_fields)
+    @fields.depends('parent', *(__on_change_parent_fields
+            + ['_parent_parent.%s' % f for f in __on_change_parent_fields]))
     def on_change_parent(self):
         if not self.parent:
             return
@@ -2293,6 +2303,7 @@ class UpdateChart(Wizard):
     @inactive_records
     def transition_update(self):
         pool = Pool()
+        Account = pool.get('account.account')
         TaxCode = pool.get('account.tax.code')
         TaxCodeTemplate = pool.get('account.tax.code.template')
         TaxCodeLine = pool.get('account.tax.code.line')
@@ -2305,7 +2316,8 @@ class UpdateChart(Wizard):
         TaxRuleLineTemplate = \
             pool.get('account.tax.rule.line.template')
 
-        account = self.start.account
+        # re-browse to have inactive context
+        account = Account(self.start.account.id)
         company = account.company
 
         # Update account types
