@@ -533,7 +533,8 @@ class Reconciliation(ModelSQL, ModelView):
                             'party1': line.party.rec_name,
                             'party2': party.rec_name,
                             })
-            if not account.company.currency.is_zero(debit - credit):
+            if (account
+                    and not account.company.currency.is_zero(debit - credit)):
                 lang = Lang.get()
                 debit = lang.currency(debit, account.company.currency)
                 credit = lang.currency(credit, account.company.currency)
